@@ -2,19 +2,22 @@
 # pylint: disable=missing-class-docstring
 # pylint: disable=missing-function-docstring
 # pylint: disable=redefined-outer-name  # in order to keep the fixture in the same file
+from typing import Iterable, List
+
 import pytest
 from pytest import approx
 
 import quantify_core.data.handling as dh
 from quantify_core.analysis import optimization_analysis as oa
+from quantify_core.data.types import TUID
 
-tuid_list = ["20210419-170747-902-9c5a05"]
+tuid_list = [TUID("20210419-170747-902-9c5a05")]
 offset_list = [[0.0008868002631485698, 0.006586920009126688]]
 POWER = -118.08462066650391
 
 
 @pytest.fixture(scope="session", autouse=True)
-def analyses(tmp_test_data_dir):
+def analyses(tmp_test_data_dir: str) -> List:
     """
     Used to run the analysis a single time and run unit tests against the created
     analysis object.
@@ -25,7 +28,7 @@ def analyses(tmp_test_data_dir):
     return analyses
 
 
-def test_figures_generated(analyses):
+def test_figures_generated(analyses: Iterable) -> None:
     """
     Test that the right figures get created.
     """
@@ -37,7 +40,7 @@ def test_figures_generated(analyses):
         }
 
 
-def test_quantities_of_interest(analyses):
+def test_quantities_of_interest(analyses: Iterable) -> None:
     """
     Test that the optimization returns the correct values
     """
