@@ -98,8 +98,12 @@ def test_getset_datadir(tmp_test_data_dir):
     os.rmdir(new_dir_path)
 
     # Test setting to None
+    dh.set_datadir(None)
+    assert dh.get_datadir() == dh.default_datadir()
+
+    # Test setting invalid type (not a directory)
     with pytest.raises(TypeError):
-        dh.set_datadir(None)
+        dh.set_datadir(5)
 
     # Test setting to empty str
     with pytest.raises(FileNotFoundError):
@@ -424,6 +428,29 @@ def test_snapshot():
     test_MC.close()
 
 
+def test_snapshot_list(tmp_test_data_dir):
+    dh.set_datadir(tmp_test_data_dir)
+    tuid = "20200430-170837-001-315f36"
+
+    experiment_directory = dh.locate_experiment_container(tuid=tuid)
+    snap = dh.snapshot()
+
+    snap["instruments"]["test_instrument"] = {"parameters": {"test_list": [1, 2, 3]}}
+
+    full_path_to_file = f"{experiment_directory}/test_snapshot_list.json"
+    with open(full_path_to_file, "w", encoding="utf-8") as file:
+        json.dump(snap, file, cls=NumpyJSONEncoder, indent=4)
+    decoded_snapshot = dh.load_snapshot(
+        tuid=tuid,
+        list_to_ndarray=True,
+        file="test_snapshot_list.json",
+    )
+    assert isinstance(
+        decoded_snapshot["instruments"]["test_instrument"]["parameters"]["test_list"],
+        np.ndarray,
+    )
+
+
 def test_snapshot_dead_instruments():
     """Ensure that the snapshot does not attempt to access dead instruments."""
     instrument_a = Instrument("a")
@@ -548,7 +575,7 @@ def test_qcodes_numpyjsonencoder():
     }
 
     encoded = json.dumps(quantities_of_interest, cls=NumpyJSONEncoder, indent=4)
-    decoded = json.loads(encoded)
+    decoded = json.loads(encoded, cls=dh.DecodeToNumpy)
 
     assert isinstance(decoded["python_tuple"], list)
     assert isinstance(decoded["python_list"], list)
@@ -568,6 +595,45 @@ def test_qcodes_numpyjsonencoder():
     assert decoded["-inf_value"] == float("-inf")
 
 
+def test_decode_list_to_numpy():
+    quantities_of_interest = {
+        "python_tuple": (1, 2, 3, 4),
+        "python_list": [1, 2, 3, 4],
+        "numpy_array": np.array([1, 2, 3, 4]),
+        "numpy_array_complex": np.array([1, 2], dtype=complex),
+        "uncertainties_ufloat": uncertainties.ufloat(1.0, 2.0),
+        "complex": complex(1.0, 2.0),
+        "nan_value": float("nan"),
+        "inf_value": float("inf"),
+        "-inf_value": float("-inf"),
+    }
+
+    encoded = json.dumps(quantities_of_interest, cls=NumpyJSONEncoder, indent=4)
+    decoded = json.loads(encoded, cls=dh.DecodeToNumpy, list_to_ndarray=True)
+
+    assert isinstance(decoded["python_tuple"], np.ndarray)
+    assert isinstance(decoded["python_list"], np.ndarray)
+    assert isinstance(decoded["numpy_array"], np.ndarray)
+    assert decoded["uncertainties_ufloat"] == {
+        "__dtype__": "UFloat",
+        "nominal_value": 1.0,
+        "std_dev": 2.0,
+    }
+    assert decoded["complex"] == {"__dtype__": "complex", "re": 1.0, "im": 2.0}
+    assert (
+        decoded["numpy_array_complex"]
+        == np.array(
+            [
+                {"__dtype__": "complex", "re": 1.0, "im": 0.0},
+                {"__dtype__": "complex", "re": 2.0, "im": 0.0},
+            ]
+        )
+    ).all()
+    assert np.isnan(decoded["nan_value"])
+    assert decoded["inf_value"] == float("inf")
+    assert decoded["-inf_value"] == float("-inf")
+
+
 def test_load_analysis_output_files(tmp_test_data_dir):
     dh.set_datadir(tmp_test_data_dir)
 
@@ -583,7 +649,6 @@ def test_load_analysis_output_files(tmp_test_data_dir):
 
 
 def test_is_uniformly_spaced_array():
-
     x0 = [1, 1.1, 1.2, 1.3, 1.4]
     x0_ng = [1, 1.1, 1.2, 1.3, 1.401]
 
@@ -604,3 +669,121 @@ def test_is_uniformly_spaced_array():
 
     for expected, points in cases:
         assert dh._is_uniformly_spaced_array(points) == expected
+
+
+def test_concat_dataset(tmp_test_data_dir):
+    dh.set_datadir(tmp_test_data_dir)
+
+    correct_tuids = dh.get_tuids_containing(
+        "Pulsed spectroscopy", t_start="2021-10-29", t_stop="2021-10-30"
+    )
+    tuid_string = "test"
+    tuid_wrong_list = dh.get_tuids_containing(
+        "Pulsed spectroscopy", t_start="2021-10-29", t_stop="2021-10-30"
+    ) + [5]
+    tuid_wrong_values = dh.get_tuids_containing(
+        "Pulsed spectroscopy", t_start="2021-10-29", t_stop="2021-10-30"
+    ) + ["test"]
+    dim_non_existing = "main_dim"
+
+    with pytest.raises(TypeError):
+        dh.concat_dataset(tuid_string)
+
+    with pytest.raises(TypeError):
+        dh.concat_dataset(tuid_wrong_list)
+
+    with pytest.raises(FileNotFoundError):
+        dh.concat_dataset(tuid_wrong_values)
+
+    with pytest.raises(KeyError):
+        dh.concat_dataset(correct_tuids, dim=dim_non_existing)
+
+    new_dataset = dh.concat_dataset(correct_tuids)
+    assert isinstance(new_dataset, xr.Dataset)
+    assert len(new_dataset.dim_0) == 720
+    assert isinstance(new_dataset["ref_tuids"], xr.DataArray)
+    assert len(new_dataset["ref_tuids"]) == 720
+    assert new_dataset["ref_tuids"].is_dataset_ref
+
+
+def test_get_varying_parameter(tmp_test_data_dir):
+    dh.set_datadir(tmp_test_data_dir)
+    instrument = "fluxcurrent"
+    parameter = "FBL_4"
+    non_existing_parameter = "FBL_5"
+    correct_tuids = dh.get_tuids_containing(
+        "Pulsed spectroscopy", t_start="2021-10-29", t_stop="2021-10-30"
+    )
+    tuid_string = "test"
+    tuid_wrong_list = dh.get_tuids_containing(
+        "Pulsed spectroscopy", t_start="2021-10-29", t_stop="2021-10-30"
+    ) + [5]
+    tuid_wrong_values = dh.get_tuids_containing(
+        "Pulsed spectroscopy", t_start="2021-10-29", t_stop="2021-10-30"
+    ) + ["test"]
+    values = np.array([-0.00100625, -0.000996875, -0.0009875])
+
+    with pytest.raises(ValueError):
+        dh.get_varying_parameter_values(tuid_string, instrument, parameter)
+
+    with pytest.raises(TypeError):
+        dh.get_varying_parameter_values(tuid_wrong_list, instrument, parameter)
+
+    with pytest.raises(ValueError):
+        dh.get_varying_parameter_values(tuid_wrong_values, instrument, parameter)
+
+    with pytest.raises(KeyError):
+        dh.get_varying_parameter_values(
+            correct_tuids, instrument, non_existing_parameter
+        )
+
+    varying_parameter_values = dh.get_varying_parameter_values(
+        correct_tuids, instrument, parameter
+    )
+    assert isinstance(varying_parameter_values, np.ndarray)
+    assert len(varying_parameter_values) == len(correct_tuids)
+    assert varying_parameter_values == pytest.approx(values)
+
+
+@pytest.mark.parametrize("new_name", [None, "concat"])
+def test_multi_experiment_data_extractor(tmp_test_data_dir, new_name):
+    dh.set_datadir(tmp_test_data_dir)
+    t_start = "20211029"
+    t_stop = "20211030"
+    instrument = "fluxcurrent"
+    parameter = "FBL_4"
+    experiment = "Pulsed spectroscopy"
+    experiment_wrong_type = 5
+    expected_varying_parameter_values = np.array(
+        [-0.00100625, -0.000996875, -0.0009875]
+    )
+
+    with pytest.raises(TypeError):
+        dh.multi_experiment_data_extractor(
+            experiment_wrong_type,
+            instrument,
+            parameter,
+            new_name=new_name,
+            t_start=t_start,
+            t_stop=t_stop,
+        )
+
+    # Test filling in all parameters and new_name=None
+    new_dataset = dh.multi_experiment_data_extractor(
+        experiment,
+        instrument,
+        parameter,
+        new_name=new_name,
+        t_start=t_start,
+        t_stop=t_stop,
+    )
+    assert len(new_dataset.dim_0) == 720
+    assert TUID.is_valid(new_dataset.attrs["tuid"])
+    assert isinstance(new_dataset.attrs["tuid"], str)
+    assert new_dataset.x1.values == pytest.approx(
+        np.repeat(expected_varying_parameter_values, 240)
+    )
+    if new_name is None:
+        assert new_dataset.name == f"{experiment} vs {instrument}"
+    else:
+        assert new_dataset.name == new_name
